@@ -1,7 +1,9 @@
 catalog_overlaps <- function(catalog)
 {
-  sfdf <- sf::st_geometry(sf::st_as_sf(catalog))
-  ii <- sf::st_intersects(sfdf)
+  geom <- sf::st_geometry(st_as_sf(catalog))
+  ii <- sf::st_intersects(geom)
+
+  if (is_lascatalog_v3(catalog)) catalog <- lascatalog_v3_repair(catalog)
 
   intersections <- vector("list", length(ii))
   for (i in 1:length(ii))
@@ -11,13 +13,13 @@ catalog_overlaps <- function(catalog)
 
     if (length(k) == 0) next
 
-    p <- sfdf[k]
-    q <- sfdf[i]
+    p <- geom[k]
+    q <- geom[i]
     w <- sf::st_intersection(q, p)
 
     intersections[[i]] <- w
   }
 
   intersections <- do.call(c, intersections)
-  sf::as_Spatial(intersections)
+  return(intersections)
 }
