@@ -70,48 +70,7 @@
 #' fun1 <- ~list(maxz = max(Z))
 #' fun2 <- ~list(q85 = quantile(Z, probs = 0.85))
 #'
-#' # ================
-#' # TEMPLATE METRICS
-#' # ================
-#'
-#' # a raster as template
-#' template <- raster::raster(extent(las), nrow = 15, ncol = 15)
-#' raster::crs(template) <- crs(las)
-#' m <- template_metrics(las, fun1, template)
-#' plot(m, col = col)
-#'
-#' # a sfc_POLYGON as template
-#' sfc <- sf::st_as_sfc(st_bbox(las))
-#' template <- sf::st_make_grid(sfc, cellsize = 20, square = FALSE)
-#' m <- template_metrics(las, fun1, template)
-#' plot(m)
-#'
-#' # a bbox as template
-#' template <- st_bbox(las) + c(50,30,-50,-70)
-#' plot(sf::st_as_sfc(st_bbox(las)), col = "gray")
-#' plot(sf::st_as_sfc(template), col = "darkgreen", add = TRUE)
-#' m <- template_metrics(las, fun2, template)
-#' print(m)
-#'
-#' # ================
-#' # CUSTOM METRICS
-#' # ================
-#'
-#' # Define a function that computes custom metrics
-#' # in an R&D perspective.
-#' myMetrics = function(z, i) {
-#'   metrics = list(
-#'      zwimean = sum(z*i)/sum(i), # Mean elevation weighted by intensities
-#'      zimean  = mean(z*i),       # Mean products of z by intensity
-#'      zsqmean = sqrt(mean(z^2))) # Quadratic mean
-#'
-#'    return(metrics)
-#' }
-#'
-#' # example with a stars template
-#' template <- stars::st_as_stars(st_bbox(las), dx = 10, dy = 10)
-#' m <- template_metrics(las, myMetrics(Z, Intensity), template)
-#' plot(m, col = col)
+#' set_lidr_threads(1) ; data.table::setDTthreads(1) # for cran only
 #'
 #' # ================
 #' # CLOUD METRICS
@@ -124,10 +83,7 @@
 #' # ================
 #'
 #' m <- pixel_metrics(las, fun1, 20)
-#' plot(m, col = col)
-#'
-#' m = pixel_metrics(las, myMetrics(Z, Intensity))
-#' plot(m, col = col)
+#' #plot(m, col = col)
 #'
 #' # ================
 #' # PLOT METRICS
@@ -138,16 +94,16 @@
 #' inventory # contains an ID and a Value Of Interest (VOI) per plot
 #'
 #' m <- plot_metrics(las, fun2, inventory, radius = 11.28)
-#' plot(header(las))
-#' plot(m["q85"], pch = 19, cex = 3, add = TRUE)
+#' #plot(header(las))
+#' #plot(m["q85"], pch = 19, cex = 3, add = TRUE)
 #'
 #' \donttest{
 #' # Works with polygons as well
 #' inventory <- sf::st_buffer(inventory, 11.28)
-#' plot(header(las))
-#' plot(sf::st_geometry(inventory), add = TRUE)
+#' #plot(header(las))
+#' #plot(sf::st_geometry(inventory), add = TRUE)
 #' m <- plot_metrics(las, .stdmetrics_z, inventory)
-#' plot(m["zq85"], pch = 19, cex = 3, add = TRUE)
+#' #plot(m["zq85"], pch = 19, cex = 3, add = TRUE)
 #' }
 #'
 #' # ================
@@ -168,19 +124,18 @@
 #' trees <- readLAS(LASfile, filter = "-drop_z_below 0")
 #'
 #' metrics <- crown_metrics(trees, .stdtreemetrics)
-#' plot(metrics["Z"], pch = 19)
+#' #plot(metrics["Z"], pch = 19)
 #'
 #' metrics <- crown_metrics(trees, .stdtreemetrics, geom = "convex")
-#' plot(metrics["Z"])
+#' #plot(metrics["Z"])
 #'
 #' metrics <- crown_metrics(trees, .stdtreemetrics, geom = "bbox")
-#' plot(metrics["Z"])
+#' #plot(metrics["Z"])
 #'
 #' \donttest{
 #' metrics <- crown_metrics(trees, .stdtreemetrics, geom = "concave")
-#' plot(metrics["Z"])
+#' #plot(metrics["Z"])
 #' }
-#'
 #' # ================
 #' # ARGUMENT FILTER
 #' # ================
@@ -208,10 +163,54 @@
 #' # func defines one metric but 3 are computed respectively for: (1) all echo types,
 #' # (2) for first returns only and (3) for multiple returns only
 #' metrics <- pixel_metrics(las, func, 20, by_echo = echo)
-#' plot(metrics, col = heat.colors(25))
+#' #plot(metrics, col = heat.colors(25))
 #'
 #' cloud_metrics(las, func, by_echo = echo)
 #'
+#' \dontrun{
+#' # ================
+#' # TEMPLATE METRICS
+#' # ================
+#'
+#' # a raster as template
+#' template <- raster::raster(extent(las), nrow = 15, ncol = 15)
+#' raster::crs(template) <- crs(las)
+#' m <- template_metrics(las, fun1, template)
+#' #plot(m, col = col)
+#'
+#' # a sfc_POLYGON as template
+#' sfc <- sf::st_as_sfc(st_bbox(las))
+#' template <- sf::st_make_grid(sfc, cellsize = 20, square = FALSE)
+#' m <- template_metrics(las, fun1, template)
+#' #plot(m)
+#'
+#' # a bbox as template
+#' template <- st_bbox(las) + c(50,30,-50,-70)
+#' plot(sf::st_as_sfc(st_bbox(las)), col = "gray")
+#' plot(sf::st_as_sfc(template), col = "darkgreen", add = TRUE)
+#' m <- template_metrics(las, fun2, template)
+#' print(m)
+#'
+#' # ================
+#' # CUSTOM METRICS
+#' # ================
+#'
+#' # Define a function that computes custom metrics
+#' # in an R&D perspective.
+#' myMetrics = function(z, i) {
+#'   metrics = list(
+#'      zwimean = sum(z*i)/sum(i), # Mean elevation weighted by intensities
+#'      zimean  = mean(z*i),       # Mean products of z by intensity
+#'      zsqmean = sqrt(mean(z^2))) # Quadratic mean
+#'
+#'    return(metrics)
+#' }
+#'
+#' # example with a stars template
+#' template <- stars::st_as_stars(st_bbox(las), dx = 10, dy = 10)
+#' m <- template_metrics(las, myMetrics(Z, Intensity), template)
+#' #plot(m, col = col)
+#' }
 #' @name aggregate
 #' @rdname aggregate
 #' @md
@@ -396,7 +395,7 @@ metrics_by_echo_type = function(las, call, cells, filter, by_echo)
   echo_types[LASMULTIPLE] <- "multiple"
   echo_types[LASLASTOFMANY] <- "lastofmany"
   echo_types[LASINTERMEDIATE] <- "intermediate"
-  echo_types1 <- echo_types[c(LASFIRST, LASINTERMEDIATE, LASLAST)]
+  echo_types1 <- echo_types[c(LASFIRST, LASINTERMEDIATE, LASLASTOFMANY)]
   echo_types2 <- echo_types[c(LASSINGLE, LASMULTIPLE)]
   echo_class  <- get_echo_type(las$ReturnNumber, las$NumberOfReturns)
   echo_class1 <- echo_class[[1]]
@@ -475,7 +474,7 @@ get_echo_type <- function(ReturnNumber, NumberOfReturns)
 
   class1 <- rep(LASINTERMEDIATE, n)
   class1[ReturnNumber == 1L] <- LASFIRST
-  class1[ReturnNumber == NumberOfReturns & ReturnNumber > 1L] <- LASLAST
+  class1[ReturnNumber == NumberOfReturns & ReturnNumber > 1L] <- LASLASTOFMANY
 
   class2 <- rep(LASMULTIPLE, n)
   class2[NumberOfReturns == 1L] <- LASSINGLE
