@@ -8,7 +8,8 @@ class Progress
 {
   public:
     Progress(unsigned int, std::string = "");
-    bool check_abort();
+    void check_abort();
+    bool check_interrupt();
     void update(unsigned int);
     void increment();
     void exit();
@@ -21,6 +22,7 @@ class Progress
     unsigned int j;
     std::string prefix;
     clock_t ti;
+    clock_t delay;
     bool display;
 };
 
