@@ -14,9 +14,9 @@ test_that("Flat surfaces have a rumple index of 1. Delaunay method", {
 })
 
 test_that("Flat surfaces have a rumple index of 1. Jenness method", {
-  skip("No longeur using sp")
-  bbox = raster::extent(0,10,0,10)
-  r = raster::raster(bbox, res = 0.5)
+  skip_if_not_installed("sp")
+  bbox = terra::ext(0,10,0,10)
+  r = terra::rast(bbox, res = 0.5)
   r[] = 2.56
 
   expect_equal(rumple_index(r), 1)
